anthropic.core

Idiomatic Clojure wrapper over the official Anthropic Java SDK (com.anthropic/anthropic-java).

Build a request as a Clojure map, get a Clojure map back. The client reads ANTHROPIC_API_KEY from the environment by default.

Idiomatic Clojure wrapper over the official Anthropic Java SDK
(`com.anthropic/anthropic-java`).

Build a request as a Clojure map, get a Clojure map back. The client reads
`ANTHROPIC_API_KEY` from the environment by default.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries