Idiomatic Clojure wrapper for the beta Messages API.
Idiomatic Clojure wrapper for the beta Messages API.
(count-beta-tokens client req)(count-beta-tokens client req opts)Count beta Messages input tokens without creating a message.
Count beta Messages input tokens without creating a message.
(create-beta-message client req)(create-beta-message client req opts)Send a beta Messages request and return a generic Clojure map response.
Send a beta Messages request and return a generic Clojure map response.
(run-beta-tools client params)(run-beta-tools client params opts)Run beta Messages with local tool functions until no tool is requested.
Options include :max-iterations, :on-message, and :on-turn. :on-turn
receives each assistant response and the current params, and returns params
for the next iteration, allowing tools and request settings to change.
Run beta Messages with local tool functions until no tool is requested. Options include `:max-iterations`, `:on-message`, and `:on-turn`. `:on-turn` receives each assistant response and the current params, and returns params for the next iteration, allowing tools and request settings to change.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |