anthropic.beta.messages

Idiomatic Clojure wrapper for the beta Messages API.

Idiomatic Clojure wrapper for the beta Messages API.
raw docstring

beta-batch-resultsclj

(beta-batch-results client id)
source

cancel-beta-batchclj

(cancel-beta-batch client id)
source

count-beta-tokensclj

(count-beta-tokens client req)
(count-beta-tokens client req opts)

Count beta Messages input tokens without creating a message.

Count beta Messages input tokens without creating a message.
sourceraw docstring

create-beta-batchclj

(create-beta-batch client req)
source

create-beta-messageclj

(create-beta-message client req)
(create-beta-message client req opts)

Send a beta Messages request and return a generic Clojure map response.

Send a beta Messages request and return a generic Clojure map response.
sourceraw docstring

delete-beta-batchclj

(delete-beta-batch client id)
source

get-beta-batchclj

(get-beta-batch client id)
source

list-beta-batchesclj

(list-beta-batches client)
(list-beta-batches client opts)
source

reduce-beta-batch-resultsclj

(reduce-beta-batch-results client id f init)
source

run-beta-toolsclj

(run-beta-tools client params)
(run-beta-tools client params opts)

Run a beta Messages request with local tool functions until no tool is requested.

Run a beta Messages request with local tool functions until no tool is requested.
sourceraw docstring

stream-beta-messageclj

(stream-beta-message client req on-event)
source

stream-beta-textclj

(stream-beta-text client req on-text)
source

cljdoc builds & hosts documentation for Clojure/Script libraries